==> zio-aws-apigatewayv2_3-5.17.127.1-sources.jar: zio/aws/apigatewayv2/model/DeleteAuthorizerRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteAuthorizerRequest(
    apiId: __string,
    authorizerId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest = {
    import DeleteAuthorizerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .authorizerId(__string.unwrap(authorizerId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteAuthorizerRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteAuthorizerRequest.wrap(buildAwsValue())
}
object DeleteAuthorizerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteAuthorizerRequest =
      zio.aws.apigatewayv2.model.DeleteAuthorizerRequest(apiId, authorizerId)
    def apiId: __string
    def authorizerId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getAuthorizerId: ZIO[Any, Nothing, __string] = ZIO.succeed(authorizerId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest
  ) extends zio.aws.apigatewayv2.model.DeleteAuthorizerRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val authorizerId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.authorizerId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest
  ): zio.aws.apigatewayv2.model.DeleteAuthorizerRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_3-5.17.145.1-sources.jar: zio/aws/apigatewayv2/model/DeleteAuthorizerRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteAuthorizerRequest(
    apiId: __string,
    authorizerId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest = {
    import DeleteAuthorizerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .authorizerId(authorizerId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteAuthorizerRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteAuthorizerRequest.wrap(buildAwsValue())
}
object DeleteAuthorizerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteAuthorizerRequest =
      zio.aws.apigatewayv2.model.DeleteAuthorizerRequest(apiId, authorizerId)
    def apiId: __string
    def authorizerId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getAuthorizerId: ZIO[Any, Nothing, __string] = ZIO.succeed(authorizerId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest
  ) extends zio.aws.apigatewayv2.model.DeleteAuthorizerRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val authorizerId: __string = impl.authorizerId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteAuthorizerRequest
  ): zio.aws.apigatewayv2.model.DeleteAuthorizerRequest.ReadOnly = new Wrapper(
    impl
  )
}
